@@ -8,10 +8,6 @@
  * file that was distributed with this source code.
  */
 
-//@require 'Swift/Mime/Attachment.php';
-//@require 'Swift/Mime/ContentEncoder.php';
-//@require 'Swift/KeyCache.php';
-//@require
 
 /**
  * An embedded file, in a multipart message.
@@ -27,13 +23,14 @@ class Swift_Mime_EmbeddedFile extends Swift_Mime_Attachment
    * @param Swift_Mime_HeaderSet $headers
    * @param Swift_Mime_ContentEncoder $encoder
    * @param Swift_KeyCache $cache
+   * @param Swift_Mime_Grammar $grammar
    * @param array $mimeTypes optional
    */
   public function __construct(Swift_Mime_HeaderSet $headers,
     Swift_Mime_ContentEncoder $encoder, Swift_KeyCache $cache,
-    $mimeTypes = array())
+    Swift_Mime_Grammar $grammar, $mimeTypes = array())
   {
-    parent::__construct($headers, $encoder, $cache, $mimeTypes);
+    parent::__construct($headers, $encoder, $cache, $grammar, $mimeTypes);
     $this->setDisposition('inline');
     $this->setId($this->getId());
   }
